#############
Feature List
#############

This page outlines the main features in the `SkyPy` library.

Galaxies
--------

- `Luminosity Distributions`_
- `Morphological Distributions`_
- `Redshift Distributions`_
- `Spectral Energy Distribution Modelling`_
- `Stellar Mass Distributions`_

.. _Luminosity Distributions: https://skypy.readthedocs.io/en/latest/galaxies.html#module-skypy.galaxies.luminosity
.. _Morphological Distributions: https://skypy.readthedocs.io/en/latest/galaxies.html#module-skypy.galaxies.morphology
.. _Redshift Distributions: https://skypy.readthedocs.io/en/latest/galaxies.html#module-skypy.galaxies.redshift
.. _Spectral Energy Distribution Modelling: https://skypy.readthedocs.io/en/latest/galaxies.html#module-skypy.galaxies.spectrum
.. _Stellar Mass Distributions: https://skypy.readthedocs.io/en/latest/galaxies.html#module-skypy.galaxies.stellar_mass
